@@ -27,21 +27,20 @@
 #include <cppunit/TextTestRunner.h>
 #include <cppunit/XmlOutputter.h>
 
-#include <gnuradio/unittests.h>
 #include "qa_radar.h"
+#include <gnuradio/unittests.h>
 #include <iostream>
 
-int
-main (int argc, char **argv)
+int main(int argc, char** argv)
 {
-  CppUnit::TextTestRunner runner;
-  std::ofstream xmlfile(get_unittest_path("radar.xml").c_str());
-  CppUnit::XmlOutputter *xmlout = new CppUnit::XmlOutputter(&runner.result(), xmlfile);
+    CppUnit::TextTestRunner runner;
+    std::ofstream xmlfile(get_unittest_path("radar.xml").c_str());
+    CppUnit::XmlOutputter* xmlout = new CppUnit::XmlOutputter(&runner.result(), xmlfile);
 
-  runner.addTest(qa_radar::suite());
-  runner.setOutputter(xmlout);
+    runner.addTest(qa_radar::suite());
+    runner.setOutputter(xmlout);
 
-  bool was_successful = runner.run("", false);
+    bool was_successful = runner.run("", false);
 
-  return was_successful ? 0 : 1;
+    return was_successful ? 0 : 1;
 }
